@@ -16,7 +16,9 @@ from celery.app.defaults import DEFAULTS
 from celery.bootsteps import RUN, CLOSE, StartStopStep
 from celery.concurrency.base import BasePool
 from celery.datastructures import AttributeDict
-from celery.exceptions import SystemTerminate, TaskRevokedError
+from celery.exceptions import (
+    WorkerShutdown, WorkerTerminate, TaskRevokedError,
+)
 from celery.five import Empty, range, Queue as FastQueue
 from celery.utils import uuid
 from celery.worker import components
@@ -268,9 +270,9 @@ class test_Consumer(AppCase):
         l.event_dispatcher = mock_event_dispatcher()
         l.task_consumer = Mock()
         l.connection = Mock()
-        l.connection.drain_events.side_effect = SystemExit()
+        l.connection.drain_events.side_effect = WorkerShutdown()
 
-        with self.assertRaises(SystemExit):
+        with self.assertRaises(WorkerShutdown):
             l.loop(*l.loop_args())
         self.assertTrue(l.task_consumer.register_callback.called)
         return l.task_consumer.register_callback.call_args[0][0]
@@ -918,10 +920,10 @@ class test_WorkController(AppCase):
         with self.assertRaises(KeyboardInterrupt):
             worker._process_task(task)
 
-    def test_process_task_raise_SystemTerminate(self):
+    def test_process_task_raise_WorkerTerminate(self):
         worker = self.worker
         worker.pool = Mock()
-        worker.pool.apply_async.side_effect = SystemTerminate()
+        worker.pool.apply_async.side_effect = WorkerTerminate()
         backend = Mock()
         m = create_message(backend, task=self.foo_task.name, args=[4, 8, 10],
                            kwargs={})
@@ -946,7 +948,7 @@ class test_WorkController(AppCase):
         worker1 = self.create_worker()
         worker1.blueprint.state = RUN
         stc = MockStep()
-        stc.start.side_effect = SystemTerminate()
+        stc.start.side_effect = WorkerTerminate()
         worker1.steps = [stc]
         worker1.start()
         stc.start.assert_called_with(worker1)
@@ -955,7 +957,7 @@ class test_WorkController(AppCase):
         worker2 = self.create_worker()
         worker2.blueprint.state = RUN
         sec = MockStep()
-        sec.start.side_effect = SystemExit()
+        sec.start.side_effect = WorkerShutdown()
         sec.terminate = None
         worker2.steps = [sec]
         worker2.start()
